@@ -164,6 +164,11 @@ if [ "$MODE" = "start" ] ; then
     brctl setfd $IFACE $IF_BRIDGE_FD
   fi
 
+  if [ "$IF_BRIDGE_TOKEN" ]
+  then
+    ip token set $IF_BRIDGE_TOKEN dev $IFACE
+  fi
+
 
   # We activate the bridge
   ip link set dev $IFACE up
